========  ===========  ===============================================================================
Key       Type         Description                                                                    
========  ===========  ===============================================================================
ID        ``int64``    Emission line ID number                                                        
NAME      ``str_``     Name of the emission line                                                      
RESTWAVE  ``float64``  Rest wavelength of the emission line                                           
ACTION    ``str_``     Action to take for this emission line; see :ref:`emission-line-modeling-action`
TIE_ID    ``int64``    ID of the line to which this one is tied.                                      
TIE_FLUX  ``str_``     Tying parameter for the flux of each line.                                     
TIE_VEL   ``str_``     Tying parameter for the velocity of each line.                                 
TIE_SIG   ``str_``     Tying parameter for the dispersion of each line.                               
========  ===========  ===============================================================================

